@@ -59,7 +59,7 @@ class PowerShellExtension(ShellExtensionPoint):
 
     def __init__(self):  # noqa: D107
         super().__init__()
-        satisfies_version(ShellExtensionPoint.EXTENSION_POINT_VERSION, '^2.1')
+        satisfies_version(ShellExtensionPoint.EXTENSION_POINT_VERSION, '^2.2')
 
         # HACK heuristics to determine if the parent shell is PowerShell
         if sys.platform == 'win32':
@@ -102,6 +102,12 @@ class PowerShellExtension(ShellExtensionPoint):
                 'prefix_script_no_ext': 'local_setup',
             })
 
+        return [
+            prefix_env_path,
+            prefix_util_path,
+            prefix_chain_env_path,
+        ]
+
     def create_package_script(  # noqa: D102
         self, prefix_path, pkg_name, hooks
     ):
@@ -116,6 +122,7 @@ class PowerShellExtension(ShellExtensionPoint):
                 'hooks': list(filter(
                     lambda hook: str(hook[0]).endswith('.ps1'), hooks)),
             })
+        return [pkg_env_path]
 
     def create_hook_append_value(  # noqa: D102
         self, env_hook_name, prefix_path, pkg_name, name, subdirectory,
@@ -178,7 +185,7 @@ class PowerShellExtension(ShellExtensionPoint):
             raise RuntimeError(
                 "Could not find '{powershell_executable_name}' executable"
                 .format(powershell_executable_name=powershell_executable_name))
-        cmd = [POWERSHELL_EXECUTABLE, '-Command', ' '.join(cmd)]
+        cmd = [POWERSHELL_EXECUTABLE, '-NoProfile', '-Command', ' '.join(cmd)]
         env = await get_environment_variables(
             cmd, cwd=str(build_base), shell=False)
 
